type ('a, 'b) page = page
type options = options
type 'b return = return
type 'a result = result

include "eliom_reg_simpl.mli"
